@@ -377,7 +377,7 @@ def slurm(ctx, alloc, memory, walltime, feature, module, conda_env,
         out = slurm_manager.sbatch(cmd, alloc=alloc, memory=memory,
                                    walltime=walltime, feature=feature,
                                    name=name, stdout_path=stdout_path,
-                                   conda_env=conda_env, module=module)
+                                   conda_env=conda_env, module=module)[0]
         if out:
             msg = ('Kicked off reV SC job "{}" (SLURM jobid #{}).'
                    .format(name, out))
